# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
import requests
import urllib

from django.conf import settings
from django.views.generic import FormView, TemplateView
from django.utils.translation import ugettext_lazy as _
from django.http import HttpResponse, HttpResponseRedirect
from django.contrib import messages

from combo.utils import sign_url

from .forms import FamilyLinkForm

ERROR_MESSAGES = {
    100: _('Wrong credentials: make sure you typed them correctly.'),
    101: _('This family account is blocked.')
}

DEFAULT_ERROR = _('Failed to link to family. Please check your credentials and retry later.')


class FamilyLinkView(FormView):
    form_class = FamilyLinkForm
    template_name = 'family/link_form.html'

    def get_success_url(self):
        if self.request.META.get('HTTP_REFERER'):
            return self.request.META['HTTP_REFERER']
        # return to current location if no referer
        return '.'

    def form_valid(self, form):
        url = settings.FAMILY_SERVICE.get('url') + '/family/link'
        if hasattr(self.request, 'session') and \
           self.request.session.get('mellon_session'):
            mellon = self.request.session['mellon_session']
            params = urllib.urlencode({'NameID': mellon['name_id_content'],
                            'orig': self.request.get_host(),
                            'login': form.cleaned_data['family_id'],
                            'password': form.cleaned_data['family_code']})
            url = sign_url(url + '?' + params, settings.FAMILY_SERVICE.get('signature_key'))
            r = requests.get(url)
            if not r.ok or r.json().get('err'):
                err_code = r.json()['err']
                messages.error(self.request, ERROR_MESSAGES.get(err_code, DEFAULT_ERROR))
            else:
                messages.info(self.request, _('Your account was successfully linked.'))
        return super(FamilyLinkView, self).form_valid(form)


class FamilyUnlinkView(TemplateView):
    template_name = 'family/unlink_confirm.html'

    def post(self, request, *args, **kwargs):
        url = settings.FAMILY_SERVICE.get('url') + '/family/unlink'
        if hasattr(request, 'session') and \
           request.session.get('mellon_session'):
            mellon = request.session['mellon_session']
            params = urllib.urlencode({'NameID': mellon['name_id_content'],
                                'orig': request.get_host()})
            url = sign_url(url + '?' + params, settings.FAMILY_SERVICE.get('signature_key'))
            r = requests.get(url)
            if not r.ok or r.json().get('err'):
                messages.error(request, _('An error occured when unlinking.'))
            else:
                messages.info(request, _('Your account was successfully unlinked.'))

        if self.request.META.get('HTTP_REFERER'):
            return HttpResponseRedirect(self.request.META['HTTP_REFERER'])
        # fallback to homepage if no referer
        return HttpResponseRedirect('/')
